<?php
# $Id: multisign.php,v 1.3 2016/03/24 13:27:12 rp Exp $
#
# PDFlib PLOP DS:
# Demonstrate digital signature features with optional signature visualization
#

try {
    # create a new PLOP object
    $plop = new PLOP();

    # Basic signature options
    $sign_opts =
        "ltv=try " .        /* use ltv=full to ensure LTV status */
        /* use the following line for PKCS11 usage
	"engine=pkcs#11 digitalid={filename=cryptoki.dll} "
	*/
        "engine=builtin digitalid={filename=demo_signer_rsa_2048.p12} password={demo} " ;


    # This is where input files live. Adjust as necessary.
    $searchpath = "../data ../../data";

    $PKCS11 = false;

    $infile = array("invoice.pdf", 
		    "PLOP-datasheet.pdf");

    $optlist;

    $optlist = sprintf("searchpath={%s}", $searchpath);
    $plop->set_option($optlist);

    if ($plop->prepare_signature($sign_opts) == 0)
    {
	die("Error: " . $plop->get_apiname() . ": "
				 . $plop->get_errmsg() . "\n");
    }

    for ($i = 0; $i < count($infile); $i++){
	printf ("Signing '%s' ", $infile[$i]);

	if (($doc = $plop->open_document($infile[$i], "")) == 0)
	{
	    print("Error: " . $plop->get_apiname() . ": "
				     . $plop->get_errmsg() . "<br/>\n");
	     continue;
	}
	$signed_name = sprintf("%s-signed.pdf", $infile[$i]);

	if ($plop->create_document($signed_name, "input=". $doc) == 0)
	{
	    printf("Error: " . $plop->get_apiname() . ": "
				     . $plop->get_errmsg() . "<br/>\n");
	    if ($PKCS11){
	        /* The PKCS#11 session may have expired;
	         * restart and try again.
	         */
		if ($plop->prepare_signature($sign_opts) == 0)
		{
		    die("Error: " . $plop->get_apiname() . ": "
					     . $plop->get_errmsg() . "<br/>\n");
		}

		if ($plop->create_document($signed_name, "input=". $doc) == 0)
		{
		    die("Error: " . $plop->get_apiname() . ": "
					     . $plop->get_errmsg() . "<br/>\n");
		}
	    }
	}
	printf ('<a href="%s">Link</a><br>', $signed_name);
	$plop->close_document($doc, "");
    }
}
catch (PLOPException $e) {
    die("PLOP exception occurred in multisign sample:\n" .
	"[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
	$e->get_errmsg() . "\n");
    }
catch (Exception $e) {
    die($e);
}

$plop = 0;
