# PDFlib PLOP DS:
# Demonstrate digital signature features with optional signature visualization
#
# $Id: sign.py,v 1.17 2016/03/24 13:27:12 rp Exp $

from sys import *
from traceback import print_tb
from PDFlib.PLOP import *

# Basic signature options 

# use ltv=full to ensure LTV status
# for  use with PKCS11
# "engine=pkcs#11 digitalid={filename=cryptoki.dll} "
sign_opts = \
    "ltv=try " \
    "engine=builtin digitalid={filename=demo_signer_rsa_2048.p12} password={demo} "
    

# This is where input files live. Adjust as necessary.
searchpath = "../data"

# Set to 1 to enable signature visualization 
visualize = 1
visfile = "signing_man_pdfa1a.pdf"

if len(argv) != 3 :
    raise Exception("usage: sign <infile> <outfile>" )

# create a new PLOP object
plop = PLOP()

try:
    optlist = "searchpath={%s}" % searchpath
    plop.set_option(optlist)

    doc = plop.open_document(argv[1], "")
    if (doc == -1):
        raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    optlist = sign_opts;        

    if (visualize):
        visdoc = plop.open_document(visfile, "")
        if (visdoc == -1):
            raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                     plop.get_errmsg()))
        optlist += "field={visdoc=%d rect={50 50 adapt adapt}} " % visdoc

    if (plop.prepare_signature(optlist) == -1):
        raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    optlist = "input={%d}" % doc
    if (plop.create_document(argv[2], optlist) == -1):
        raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    plop.close_document(doc, "")
    if (visualize):
        plop.close_document(visdoc, "")

except PLOPException:
    print("PDFlib PLOP exception occurred:\n[%d] %s: %s" %
        ((plop.get_errnum()), plop.get_apiname(), plop.get_errmsg()))
    print_tb(exc_info()[2])

except Exception:
    print("Exception occurred: %s" % (exc_info()[0]))
    print_tb(exc_info()[2])

finally:
    plop.delete()
